
/*******************************************************************************************************************

 (C) Copyright  Marvell Semiconductor Hefei branch Ltd. All Rights Reserved  

 *******************************************************************************************************************/
#include "Macrodef.h"
#include "../WtptpDownLoad/ParaDefine.h"
#include "RndParadef.h"
#ifdef IFLSWD_STATIC
#include "BLFProperty.h"
#endif

#ifdef IFLSWD_DYNAMIC
#ifdef IFLSWD_EXPORTS
#define IFLSWD_FUNC extern "C" __declspec(dllexport)
#else
#define IFLSWD_FUNC extern "C" __declspec(dllimport)
#endif
#else
#define IFLSWD_FUNC
#endif


/*! @defgroup groupFunctions function list
* @{
*/
/// =========================================
/// @fn			ReadBLF(PInstanceParams PInstParam,char * pszBLFfileName)
/// @brief		Read and Parse blf file and generate temp folder for download
/// @param[in]	pszBLFfileName 
/// @param[out] PInstParam including download file list and DKB files name and other configurations.                                                                 
/// @return		bool.
///				@retval true : Successfully .  
///				@retval false : Failed .
/// @note		This function is used in user only provide separated images to download\n
///
/// =========================================
IFLSWD_FUNC bool ReadBLF(PInstanceParams pInstParam,const TCHAR * pszBLFfileName);

/*! @defgroup groupFunctions function list
* @{
*/
/// =========================================
/// @fn			PrepareUpload(PInstanceParams PInstParam,char * pszUploadCfgfileName)
/// @brief		Read and Parse upload configuration file and do preparations
/// @param[in]	pszBLFfileName 
/// @param[out] PInstParam including download file list and DKB files name and other configurations.                                                                 
/// @return		bool.
///				@retval true : Successfully .  
///				@retval false : Failed .
/// @note		This function is used to generate a Realiable data format file\n
///
/// =========================================
IFLSWD_FUNC bool PrepareUpload(PInstanceParams PInstParam,const TCHAR * pszUploadCfgfileName);
//#if !defined(LINUX)
/// =========================================
/// @fn			RNDBuilder(RNDEntryParams* pRNDEnParas, char *pszRNDfileName)
/// @brief		Generate a Reliable Data file 
/// @param[in]	pszRNDfileName 
/// @param[out] pRNDEnParas.                                                           
/// @details	User need to input files and enry type to pRNDEnParas 
/// @return		bool.
///				@retval true : Successfully .  
///				@retval false : Failed .
/// @note		please see detail of structure of pRNDEnParas comments of each parameter\n 
///
/// =========================================
IFLSWD_FUNC bool  RNDBuilder(RNDEntryParams* pRNDEnParas, const TCHAR *pszRNDfileName);

//#endif

IFLSWD_FUNC bool RNDParser(const TCHAR *pszRNDfileName, const TCHAR *pszDestDir, list<FLASH_ENTRY_INFO>& flashEntryInfo);

/// =========================================
/// @fn			RRNDParser(const char *pszRNDfileName, FLASH_RD_PARSE* const pFlashRdParse)
/// @brief		Generate some bin files through parsing a Reliable Data file
/// @param[in]	pszRNDfileName 
/// @param[in]  pFlashRdParse                                                           
/// @details	User need to input  Reliable Data file name and structor FLASH_RD_PARSE type 
/// @return		bool.
///				@retval true : Successfully .  
///				@retval false : Failed .
/// @note		please see detail of structure of FLASH_RD_PARSE comments of each parameter\n 
///
/// =========================================
//bool RNDParser(const char *pszRNDfileName, FLASH_RD_PARSE* const pFlashRdParse);

/// =========================================
/// @fn			SetMode(unsigned int Command)
/// @brief		Set User command
/// @param[in]	Command    
/// @return		bool.
///				@retval true : Successfully .  
///				@retval false : Failed .
/// @note		This function is for reserved use\n
/// =========================================
IFLSWD_FUNC bool  SetMode(unsigned int Command);


/// =========================================
/// @fn			PrepareDownloadWithFBF(PInstanceParams PInstParam,char * pszBLFfileName ,char* pszFlasherfileName,char *pszFBFfileName)
/// @brief		Parse blf file and generate temp folder for download
/// @param[in]	pszBLFfileName 
/// @param[in]	pszFBFfileName 
/// @param[out] PInstParam including download file list and DKB files name and other configurations.     
/// @return		bool.
///				@retval true : Successfully .  
///				@retval false : Failed .
/// @note		This function is used in user only provide a prepared FBF file in production,\n
///				This API is better in production line,but user need to prepare FBF file first\n
///				How to Generate FBF file , there are two steps: \n
///				1, run NtimBuild.exe to generate a tim header file;\n
///				2, run FBF_Make.exe to generate a FBF file.\n
///
/// =========================================
IFLSWD_FUNC  bool PrepareDownloadWithFBF(PInstanceParams pInstParam,const TCHAR * pszBLFfileName ,const TCHAR* pszFlasherfileName,const TCHAR *pszFBFfileName);

/// =========================================
/// @fn			GetBlfInfo(char * pszBLFfileName,BlfInfoProperty* pBLFInfo)
/// @brief		Parse blf file and generate temp folder for download
/// @param[in]	pszBLFfileName 
/// @param[in]	pszFlasherfileName 
/// @param[in]	pszFBFfileName 
/// @param[out] pBLFInfo including all information of blf file.                                                                 
/// @return		bool.
///				@retval true : Successfully .  
///				@retval false : Failed .
/// @note		This function is used in user need to do modifications of configurations in blf file in their UI\n
///				This API is NOT recommend in production line tool, it is better use in development phase's tool\n
///				because it is too flexible \n 
///
/// =========================================

#ifdef IFLSWD_STATIC
bool  GetBlfInfo(const TCHAR * pszBLFfileName,BlfInfoProperty* pBLFInfo);
#endif

/// =========================================
/// @fn			SetBlfInfo(char * pszBLFfileName,BlfInfoProperty* pBLFInfo)
/// @brief		Parse blf file and generate temp folder for download
/// @param[in]	pszBLFfileName
/// @param[out] pBLFInfo including all information of blf file.                                                             
/// @return		bool.
///				@retval true : Successfully .  
///				@retval false : Failed .
/// @note		This function is used in user have Modified configurations of blf file in their UI \n
///				and need to save those changes into blf file for future usage \n
///				This API is NOT recommend in production line tool, it is better use in development phase's tool\n
///				because it is too flexible \n
///
/// =========================================
#ifdef IFLSWD_STATIC
bool SetBlfInfo(const TCHAR * pszBLFfileName,BlfInfoProperty* pBLFInfo);
#endif
/// =========================================
/// @fn			DoFBFMakeforSplitImage(const char * pszBLFfileName,const char * pszSplitSize)
/// @brief		Parse blf file and make a special FBF file as user request that split an image to 
///             several images 
/// @param[in]	pszBLFfileName 
/// @param[in]	pszSplitSize 
/// @param[out] fbf.bin file.                                                             
/// @return		bool.
///				@retval true : Successfully .  
///				@retval false : Failed .
/// @note		This function is used for speical case to split an large image to serveral images by splitsize user set and 
///				wrap all images into a fbf file \n
///
/// =========================================
IFLSWD_FUNC bool DoFBFMakeforSplitImage(const TCHAR * pszBLFfileName,const TCHAR * pszSplitSize);

/// =========================================
/// @fn			NTimBuilder(const char * pszBLFfileName)
/// @brief		Parse blf file and generate a tim file as the name described in blf file 
///             it will be have the same path as blf file
/// @param[in]	pszBLFfileName 
/// @param[out] tim file.                                                             
/// @return		bool.
///				@retval true : Successfully .  
///				@retval false : Failed .
/// @note		this function is used to generate a tim/ntim file  \n
///
/// =========================================
IFLSWD_FUNC bool NTimBuilder(const TCHAR * pszBLFfileName);

/// =========================================
/// @fn			FBFMake(const char * pszBLFfileName,const char * pszFBFfileName)
/// @brief		Parse blf file and generate fbf file as user input 
///             it will be have the same path as blf file
/// @param[in]	pszBLFfileName 
/// @param[out] pszFBFfileName.                                                             
/// @return		bool.
///				@retval true : Successfully .  
///				@retval false : Failed .
/// @note		this function is used to generate a FBF format file for preparedownloadwithFBF \n
///
/// =========================================
IFLSWD_FUNC bool  FBFMake(const TCHAR * pszBLFfileName,const TCHAR * pszFBFfileName);

/// =========================================
/// @fn			PInstanceParams IFLSWD_FUNC GetInstanceParams()
/// @brief		Malloc memory for  PInstanceParams to let user use
///             it will return a pointer
/// @param[in]	NULL 
/// @param[out] PInstanceParams.                                                             
/// @return		bool.
///				@retval non NULL : Successfully .  
///				@retval NULL : Failed .
/// @note		this function is used to new a PInstanceParams to save parameters for use \n
///
/// =========================================
IFLSWD_FUNC  PInstanceParams MallocInstanceParams();

/// =========================================
/// @fn			bool IFLSWD_FUNC FreeInstanceParams(PInstanceParams pInstParam)
/// @brief		Free memory for  PInstanceParams to let user use
/// @param[in]	NULL 
/// @param[out] PInstanceParams.                                                             
/// @return		bool.
///				@retval true : Successfully .  
///				@retval false : Failed .
/// @note		this function is used to free a PInstanceParams to save parameters for use \n
///
/// =========================================
IFLSWD_FUNC bool FreeInstanceParams(PInstanceParams pInstParam);
///@}		//@defgroup groupFunctions function list


//
//#ifdef  __cplusplus
//}
//#endif
